@@ -9,8 +9,7 @@ Spreadsheet::Write - Simplified writer for CSV or XLS (MS Excel'97) files
     use Spreadsheet::Write;
 
     my $h=Spreadsheet::Write->new(
-        file    => 'spreadsheet.xls',
-        format  => 'xls',
+        file    => 'spreadsheet.xlsx',
         sheet   => 'Products',
         styles  => {
             money   => '($#,##0_);($#,##0)',
@@ -48,9 +47,9 @@ Spreadsheet::Write - Simplified writer for CSV or XLS (MS Excel'97) files
 =head1 DESCRIPTION
 
 C<Spreadsheet::Write> writes files in CSV, XLS (Microsoft Excel 97),
-and potentially other formats. It is especially suitable for building
-various dumps and reports where rows are built in sequence, one after
-another.
+XLSX (Microsoft Excel 2007), and other formats if their drivers
+exist. It is especially suitable for building various dumps and reports
+where rows are built in sequence, one after another.
 
 =head1 METHODS
 
@@ -64,7 +63,7 @@ require 5.008_009;
 use strict;
 use IO::File;
 
-our $VERSION='1.01';
+our $VERSION='1.02';
 
 sub version {
     return $VERSION;
@@ -86,7 +85,7 @@ following are valid:
 
     file        filename of the new spreadsheet or an IO handle (mandatory)
     encoding    encoding of output file (optional, csv format only)
-    format      format of spreadsheet - 'csv', 'xls', or 'auto' (default)
+    format      format of spreadsheet - 'csv', 'xls', 'xlsx', or 'auto' (default)
     sheet       Sheet name (optional, not supported by some formats)
     styles      Defines cell formatting shortcuts (optional)
 
@@ -145,6 +144,7 @@ sub new(@) {
     my $implementation={
         csv     => 'WriteCSV',
         xls     => 'WriteXLS',
+        xlsx    => 'WriteXLSX',
     }->{lc $format};
 
     $implementation ||
@@ -240,7 +240,7 @@ override style definitions.
 Example:
 
     my $sp=Spreadsheet::Write->new(
-        file        => 'employees.xls',
+        file        => 'employees.xlsx',
         styles      => {
             header => { font_weight => 'bold' },
         },
